@@ -1,6 +1,7 @@
 import collections
 import typing
 
+from ._commons import is_newtype
 from ._error import (
     AttributeTypeError,
     BadTypeError,
@@ -17,6 +18,22 @@ except ImportError:
     from collections import MutableMapping
 
 
+class SimilarTypes:
+    Dict = {
+        dict,
+        collections.OrderedDict,
+        collections.defaultdict,
+        Mapping,
+        MutableMapping,
+        typing.Dict,
+        typing.DefaultDict,
+        typing.Mapping,
+        typing.MutableMapping,
+    }
+    List = {set, list, typing.List, typing.Set}
+    Tuple = {tuple, typing.Tuple}
+
+
 def type_validator(empty_ok=True):
     """
     Validates the attributes using the type argument specified. If the
@@ -37,12 +54,15 @@ def type_validator(empty_ok=True):
 
 
 def _validate_elements(attribute, value, expected_type):
-    base_type = (
-        expected_type.__origin__
-        if hasattr(expected_type, "__origin__")
+    if (
+        hasattr(expected_type, "__origin__")
         and expected_type.__origin__ is not None
-        else expected_type
-    )
+    ):
+        base_type = expected_type.__origin__
+    elif is_newtype(expected_type):
+        base_type = expected_type.__supertype__
+    else:
+        base_type = expected_type
 
     if base_type is None or base_type == typing.Any:
         return
@@ -50,21 +70,11 @@ def _validate_elements(attribute, value, expected_type):
     if base_type != typing.Union and not isinstance(value, base_type):
         raise AttributeTypeError(value, attribute)
 
-    if base_type in {set, list, typing.List, typing.Set}:
+    if base_type in SimilarTypes.List:
         _handle_set_or_list(attribute, value, expected_type)
-    elif base_type in {
-        dict,
-        collections.OrderedDict,
-        collections.defaultdict,
-        Mapping,
-        MutableMapping,
-        typing.Dict,
-        typing.DefaultDict,
-        typing.Mapping,
-        typing.MutableMapping,
-    }:
+    elif base_type in SimilarTypes.Dict:
         _handle_dict(attribute, value, expected_type)
-    elif base_type in {tuple, typing.Tuple}:
+    elif base_type in SimilarTypes.Tuple:
         _handle_tuple(attribute, value, expected_type)
     elif base_type == typing.Union:
         _handle_union(attribute, value, expected_type)
@@ -95,6 +105,9 @@ def _handle_dict(attribute, container, expected_type):
 
 def _handle_tuple(attribute, container, expected_type):
     tuple_types = expected_type.__args__
+    if len(tuple_types) == 2 and tuple_types[1] == Ellipsis:
+        element_type = tuple_types[0]
+        tuple_types = (element_type, ) * len(container)
 
     if len(container) != len(tuple_types):
         raise TupleError(container, attribute.type, tuple_types)
